﻿using System;
using System.Linq;
using Devart.Data.Linq;
using Devart.Data.Linq.Monitoring;

namespace SqliteTest
{
    class Program
    {
        static void Main(string[] args)
        {
            // Monitor queries in dbMonitor
            using (new LinqMonitor { IsActive = true })
            {
                // Initialize
                var ctx = new Context.DataContext();
                ctx.CreateDatabase();
                ctx.TestClasses.InsertAllOnSubmit(
                    new[] { "A_B", "A_C", "AB", "B_C" }
                    .Select(s => new Context.TestClass { Label = s })
                );
                ctx.SubmitChanges();

                // LIKE without escape character
                var query1 =
                    from tc in ctx.TestClasses
                    where SqlMethods.Like(tc.Label, "A%")
                    select tc;
                Console.WriteLine("Query 1 results:");
                foreach (var r in query1)
                    Console.WriteLine("Id={0}, Label={1}", r.Id, r.Label);

                Console.WriteLine();

                // Substring (translates to escaped LIKE)
                var query2 =
                    from tc in ctx.TestClasses
                    where tc.Label.StartsWith("A_")
                    select tc;
                Console.WriteLine("Query 2 results:");
                foreach (var r in query2)
                    Console.WriteLine("Id={0}, Label={1}", r.Id, r.Label);

                Console.WriteLine();

                // LIKE with escape character
                var query3 =
                    from tc in ctx.TestClasses
                    where SqlMethods.Like(tc.Label, "A~_%", '~')
                    select tc;
                Console.WriteLine("Query 3 results:");
                foreach (var r in query3)
                    Console.WriteLine("Id={0}, Label={1}", r.Id, r.Label);
            }
        }
    }
}
